==> bacula-2.4.4-b2.tar.gz: bacula-2.4.4-b2/src/win32/libwin32/aboutDialog.h <==
/*
   Bacula® - The Network Backup Solution

   Copyright (C) 2007-2007 Free Software Foundation Europe e.V.

   The main author of Bacula is Kern Sibbald, with contributions from
   many others, a complete list can be found in the file AUTHORS.
   This program is Free Software; you can redistribute it and/or
   modify it under the terms of version two of the GNU General Public
   License as published by the Free Software Foundation and included
   in the file LICENSE.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.

   Bacula® is a registered trademark of John Walker.
   The licensor of Bacula is the Free Software Foundation Europe
   (FSFE), Fiduciary Program, Sumatrastrasse 25, 8006 Zürich,
   Switzerland, email:ftf@fsfeurope.org.
*/
/*
 * Kern Sibbald, August 2007
 *
 *   Version $Id: aboutDialog.h 5358 2007-08-15 16:54:21Z kerns $
 */

#ifndef __ABOUT_DIALOG_H_
#define __ABOUT_DIALOG_H_ 1

/* Define the aboutDialog class */
class aboutDialog
{
public:
   aboutDialog() { m_visible =false; };
  ~aboutDialog() { };

   void show(bool show);

   bool m_visible;
};

#endif /* __ABOUT_H_ */

==> bacula-3.0.2.tar.gz: bacula-3.0.2/src/win32/libwin32/aboutDialog.h <==
/*
   Bacula® - The Network Backup Solution

   Copyright (C) 2007-2007 Free Software Foundation Europe e.V.

   The main author of Bacula is Kern Sibbald, with contributions from
   many others, a complete list can be found in the file AUTHORS.
   This program is Free Software; you can redistribute it and/or
   modify it under the terms of version two of the GNU General Public
   License as published by the Free Software Foundation and included
   in the file LICENSE.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.

   Bacula® is a registered trademark of Kern Sibbald.
   The licensor of Bacula is the Free Software Foundation Europe
   (FSFE), Fiduciary Program, Sumatrastrasse 25, 8006 Zürich,
   Switzerland, email:ftf@fsfeurope.org.
*/
/*
 * Kern Sibbald, August 2007
 *
 *   Version $Id: aboutDialog.h 7380 2008-07-14 10:42:59Z kerns $
 */

#ifndef __ABOUT_DIALOG_H_
#define __ABOUT_DIALOG_H_ 1

/* Define the aboutDialog class */
class aboutDialog
{
public:
   aboutDialog() { m_visible =false; };
  ~aboutDialog() { };

   void show(bool show);

   bool m_visible;
};

#endif /* __ABOUT_H_ */
